@@ -7,8 +7,8 @@ from .modules import (
     Discriminator1d,
     Encoder1d,
     MAE1d,
+    ME1d,
     NoiserBottleneck,
     TanhBottleneck,
     VariationalBottleneck,
 )
-from .pretrained import AudioEncoders
